==> twilio_chat_plugin-0.0.5.tar.gz: example/lib/pages/login.dart <==
import 'package:flutter/material.dart';
import 'package:twilio_chat_plugin_example/shared/helpers/twilio.dart';
import 'package:twilio_chat_plugin_example/shared/services/backend_service.dart';
import 'dart:async';

import 'package:twilio_chat_plugin/twilio_chat_plugin.dart';

import 'channel_list.dart';

class LoginPage extends StatefulWidget {
  @override
  _LoginPageState createState() => _LoginPageState();
}

class _LoginPageState extends State<LoginPage> {
  final identityController = TextEditingController();

  bool isLoading = false;

  @override
  initState() {
    super.initState();
    TwilioChatPlugin.debug();
  }

  Future<void> createTokenFromCF(String identity, BuildContext context) async {
    setState(() {
      isLoading = true;
    });
    final accessToken = await FirebaseFunctions.instance.createToken(identity);
      final chatClient =
          await TwilioChatPlugin.createChatClient(accessToken, null);
    TwilioHelper(chatClient);
    setState(() {
      isLoading = false;
    });
    if (chatClient != null) {
      Navigator.push(
        context,
        MaterialPageRoute(builder: (context) => ChannelListPage()),
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Twilio Chat Example'),
      ),
      body: Column(
        children: <Widget>[
          SizedBox(height: 20),
          Container(
            padding: EdgeInsets.all(20),
            child: TextField(
              controller: identityController,
              decoration: InputDecoration(hintText: 'Enter a name here'),
            ),
          ),
          SizedBox(height: 20),
          isLoading
              ? CircularProgressIndicator()
              : MaterialButton(
                  color: Colors.blue,
                  textColor: Colors.white,
                  child: Text('Confirm'),
                  onPressed: () {
                    createTokenFromCF(identityController.text, context);
                  },
                )
        ],
      ),
    );
  }
}

==> twilio_chat_plugin-0.0.6.tar.gz: example/lib/pages/login.dart <==
import 'package:flutter/material.dart';
import 'package:twilio_chat_plugin_example/shared/helpers/twilio.dart';
import 'dart:async';

import 'package:twilio_chat_plugin/twilio_chat_plugin.dart';
import 'package:twilio_chat_plugin_example/shared/services/backend_service.dart';

import 'channel_list.dart';

class LoginPage extends StatefulWidget {
  @override
  _LoginPageState createState() => _LoginPageState();
}

class _LoginPageState extends State<LoginPage> {
  final identityController = TextEditingController();

  bool isLoading = false;

  @override
  initState() {
    super.initState();
    TwilioChatPlugin.debug();
  }

  Future<void> createTokenFromCF(String identity, BuildContext context) async {
    setState(() {
      isLoading = true;
    });
    final accessToken = await FirebaseFunctions.instance.createToken(identity);
    final chatClient =
        await TwilioChatPlugin.createChatClient(accessToken, null)
            .timeout(Duration(seconds: 7))
            .catchError((Object e) {
      print(e);
      if (e.runtimeType == TimeoutException) return;
      return null;
    });
    chatClient.attachListener();
    TwilioHelper(chatClient);
    setState(() {
      isLoading = false;
    });
    if (chatClient != null) {
      listenToTokenChange(chatClient, identity);
      Navigator.push(
        context,
        MaterialPageRoute(builder: (context) => ChannelListPage()),
      );
    }
  }

  listenToTokenChange(ChatClient chatClient, String identity) {
    chatClient.onTokenAboutToExpire.listen((data) async {
      final accessToken =
          await FirebaseFunctions.instance.createToken(identity);
      await TwilioChatPlugin.createChatClient(accessToken, null)
          .timeout(Duration(seconds: 10))
          .catchError((Object e) {
        print(e);
        if (e.runtimeType == TimeoutException) return;
        return null;
      });
    });
    chatClient.onTokenExpired.listen((data) async {
      final accessToken =
          await FirebaseFunctions.instance.createToken(identity);
      await TwilioChatPlugin.createChatClient(accessToken, null)
          .timeout(Duration(seconds: 10))
          .catchError((Object e) {
        print(e);
        if (e.runtimeType == TimeoutException) return;
        return null;
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Twilio Chat Example'),
      ),
      body: Column(
        children: <Widget>[
          SizedBox(height: 20),
          Container(
            padding: EdgeInsets.all(20),
            child: TextField(
              controller: identityController,
              decoration: InputDecoration(hintText: 'Enter a name here'),
            ),
          ),
          SizedBox(height: 20),
          isLoading
              ? CircularProgressIndicator()
              : MaterialButton(
                  color: Colors.blue,
                  textColor: Colors.white,
                  child: Text('Confirm'),
                  onPressed: () {
                    createTokenFromCF(identityController.text, context);
                  },
                )
        ],
      ),
    );
  }
}
